GDALRasterBand-class: Class "GDALRasterBand"
Description
Returns a two-dimensional array with data from a raster band, used internally within functionsUsage
getRasterData(dataset, band = NULL, offset = c(0, 0),
region.dim = dim(dataset), output.dim = region.dim,
interleave = c(0, 0), as.is = FALSE) getRasterTable(dataset, band = NULL, offset = c(0, 0), region.dim = dim(dataset))
getProjectionRef(dataset)
Arguments
dataset
An object inheriting from class 'GDALReadOnlyDataset'
band
The band number (1-based) to read from
offset
Number of rows and columns from the origin (usually the
upper left corner) to begin reading from
region.dim
The number of rows and columns to read from the
dataset
output.dim
Number of rows and columns in the output data; if
smaller than region.dim the data will be subsampled
interleave
Element and row stride while reading data; rarely
needed
as.is
If false, scale the data to its natural units; if the
case of thematic data, return the data as factors
Objects from the Class
Objects can be created by calls of the form new("GDALRasterBand", dataset, band).Extends
Class "GDALMajorObject", directly.Details
[object Object],[object Object],[object Object]Examples
Run this codelogo <- system.file("pictures/logo.jpg", package="rgdal")[1]
x <- new("GDALReadOnlyDataset", logo)
plot(density(getRasterTable(x)$band1))
GDAL.close(x)
Run the code above in your browser using DataLab